using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Txgy.RBS.DbModel.Models;
using Txgy.RBS.DTO;
using Txgy.RBS.Framework.Api;
using Txgy.RBS.IServices;

namespace Txgy.RBS.IServices
{
    public interface IResultInfoService : IBaseService
    {
        ApiResult AddResultInfo(ResultDTO resultJsonDTO);

        ApiResult DeleteResultInfo(int id);

        ApiResult UpdateResultInfo(ResultDTO resultJsonDTO);

        ResultDTO GetResultInfo(int id);

        List<ResultDTO> GetResultInfo(string projectName, DateTime startTime,DateTime endTime);

        List<ResultDTO> GetAllResultInfo();

        List<RedisInfoDTO> GetAllRidesInfo();

        ApiResult AddRedisInfo(RedisInfoDTO  redisServerDTO);
       
        ApiResult DeleteRedisInfo(int id);

        ApiResult UpdateRedisInfo(RedisInfoDTO  redisServerDTO);

        RedisInfoDTO GetRedisInfo(int id);

    }
}
